## dbt-adapters 1.3.0 - June 18, 2024

### Features

* Add get_catalog_for_single_relation macro and capability to enable adapters to optimize catalog generation ([#231](https://github.com/dbt-labs/dbt-adapters/issues/231))
